/*************************************************** */
/* Rule Set Based Access Control                     */
/*                                                   */
/* Author and (c) 1999-2006: Amon Ott <ao@rsbac.org> */
/*                                                   */
/* Last modified: 27/Feb/2006                        */
/*************************************************** */

#include <stdio.h>
#include <stdlib.h>
#include <pwd.h>
#include <sys/types.h>
#include <rsbac/types.h>
#include <rsbac/getname.h>
#include <rsbac/syscalls.h>
#include <rsbac/error.h>
#include "nls.h"
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

char * progname;

void use(void)
    {
      printf(gettext("%s (RSBAC %s)\n***\n"), progname, VERSION);
      printf(gettext("Use: %s [flags] group(s)\n\n"), progname);  
      printf(gettext(" -N ta = transaction number (default = value of RSBAC_TA, if set, or 0)\n"));
    }

int main(int argc, char ** argv)
{
  int res = 0;
  int i;
  union rsbac_target_id_t tid;
  rsbac_list_ta_number_t ta_number = 0;
  rsbac_um_set_id_t um_set = RSBAC_UM_SET_AUTO;

  progname = argv[0];
  locale_init();
  
  {
    char * env = getenv("RSBAC_TA");

    if(env)
      ta_number = strtoul(env,0,0);
  }
  while((argc > 1) && (argv[1][0] == '-'))
    {
      char * pos = argv[1];
      pos++;
      while(*pos)
        {
          switch(*pos)
            {
              case 'h':
                use();
                return 0;
	      case 'U':
			if (argc > 2) {
				um_set = strtoul(argv[2], 0, 10);
				argc--;
				argv++;
			} else {
				fprintf(stderr,
					gettext
					("%s: missing UM virtual set number value for parameter %c\n"),
					progname, *pos);
				exit(1);
			}
			break;
              case 'N':
                if(argc > 2)
                  {
                    ta_number = strtoul(argv[2], 0, 10);
                    argc--;
                    argv++;
                  }
                else
                  {
                    fprintf(stderr, gettext("%s: missing transaction number value for parameter %c\n"), progname, *pos);
                    exit(1);
                  }
                break;
              default:
                fprintf(stderr, gettext("%s: unknown parameter %c\n"), progname, *pos);
                exit(1);
            }
          pos++;
        }
      argv++;
      argc--;
    }

  if (argc > 1)
    {
      printf(gettext("%s: %i groups\n\n"), progname, argc - 1);
      for (i=1;i < (argc);i++)
        {
          if(rsbac_get_gid_name(ta_number, &tid.group.gid, NULL, argv[i], um_set))
            {
              fprintf(stderr, gettext("Invalid Group %s!\n\n"), argv[i]);
              continue;
            }
          tid.group.set = um_set;
          printf(gettext("Processing set %u group %s (gid %i)\n"),
                 um_set, argv[i], tid.group);

          res = rsbac_remove_target(ta_number, T_GROUP, &tid);
          show_error(res);
        }
    }
  else
    {
      use();
      return 1;
    }
    
  return (res);
}
